Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FanInConsumerGroupInfoClient ¶
type FanInConsumerGroupInfoClient struct {
Delegate exporter.ConsumerGroupInfoClient
// contains filtered or unexported fields
}
FanInConsumerGroupInfoClient is a exporter.ConsumerGroupInfoClient decorator that makes multiple same calls to exporter.ConsumerGroupInfoClient functions only yield a single call to Delegate. This is useful to avoid running too many calls to `kafka-consumer-group.sh` if things are running slow.
func (*FanInConsumerGroupInfoClient) DescribeGroup ¶
func (f *FanInConsumerGroupInfoClient) DescribeGroup(ctx context.Context, group string) ([]exporter.PartitionInfo, error)
DescribeGroup calls f.Delegate.DescribeGroup(). If multiple overlapping calls to this function with the same parameters are made, a single call will be made to the f.Delegate.
func (*FanInConsumerGroupInfoClient) Groups ¶
func (f *FanInConsumerGroupInfoClient) Groups(ctx context.Context) ([]string, error)
Groups calls f.Delegate.Groups(). If multiple overlapping calls to this function are made, a single call will be made to the f.Delegate.
func (*FanInConsumerGroupInfoClient) Stop ¶
func (f *FanInConsumerGroupInfoClient) Stop()
Stop all goroutines started by other functions.
Source Files
¶
- metrics.go